import { createSlice, PayloadAction } from "@reduxjs/toolkit";
import Cookies from "js-cookie";

interface User {
  id: number;
  name: string;
  email: string;
}

interface UserState {
  user: User | null;
  token: string | null;
}

const initialState: UserState = {
  user: Cookies.get("_user") ? JSON.parse(Cookies.get("_user") || "{}") : null,
  token: Cookies.get("_auth") || null,
};

const userSlice = createSlice({
  name: "user",
  initialState,
  reducers: {
    setUser: (state, action: PayloadAction<User | null>) => {
      state.user = action.payload;
      if (action.payload) {
        Cookies.set("_user", JSON.stringify(action.payload), { expires: 0.5 });
      } else {
        Cookies.remove("_user");
      }
    },
    setToken: (state, action: PayloadAction<string | null>) => {
      state.token = action.payload;
      console.log("Token updated:", action.payload);
      if (action.payload) {
        Cookies.set("_auth", action.payload, { expires: 0.5 });
      } else {
        Cookies.remove("_auth");
      }
    },
  },
});

export const { setUser, setToken } = userSlice.actions;
export default userSlice.reducer;
